@@ -1,10 +1,10 @@
-from datetime import datetime
+from django.utils import timezone
 
 from site_status import models
 
 
 def get_statuses():
-    current_datetime = datetime.now()
+    current_datetime = timezone.now()
 
     statuses = models.Status.objects.all()\
         .filter(start_time__lt=current_datetime)\
@@ -15,7 +15,7 @@ def get_statuses():
 
 def add_status(level, body, end_time, start_time=None):
     if start_time is None:
-        start_time = datetime.now()
+        start_time = timezone.now()
 
     status = models.Status(level=level,
                            body=body,
